@@ -9,6 +9,6 @@ def get_uuid(name):
 	json = response.json()
 	try:
 		return json["id"]
-	except KeyError:
+	except json.decoder.JSONDecodeError:
 		raise InvalidPlayerNameError
 		
\ No newline at end of file
